package kr.co.vividnext.sodalive.main

import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import com.google.gson.annotations.SerializedName
import io.reactivex.rxjava3.android.schedulers.AndroidSchedulers
import io.reactivex.rxjava3.schedulers.Schedulers
import kr.co.vividnext.sodalive.base.BaseViewModel
import kr.co.vividnext.sodalive.common.SharedPreferenceManager
import kr.co.vividnext.sodalive.settings.notification.UpdateNotificationSettingRequest
import kr.co.vividnext.sodalive.user.UserRepository

class MainViewModel(
    private val userRepository: UserRepository,
) : BaseViewModel() {
    enum class CurrentTab {
        @SerializedName("CONTENT")
        CONTENT,

        @SerializedName("LIVE")
        LIVE,

        @SerializedName("EXPLORER")
        EXPLORER,

        @SerializedName("MESSAGE")
        MESSAGE,

        @SerializedName("MY")
        MY
    }

    private val _currentTab = MutableLiveData(CurrentTab.LIVE)
    val currentTab: LiveData<CurrentTab>
        get() = _currentTab

    fun clickTab(tab: CurrentTab) {
        if (_currentTab.value != tab) {
            _currentTab.postValue(tab)
        }
    }

    fun updateNotificationSettings(
        isNotifiedLive: Boolean,
        isNotifiedUploadContent: Boolean,
        isNotifiedMessage: Boolean
    ) {
        compositeDisposable.add(
            userRepository.updateNotificationSettings(
                request = UpdateNotificationSettingRequest(
                    isNotifiedLive,
                    isNotifiedUploadContent,
                    isNotifiedMessage
                ),
                token = "Bearer ${SharedPreferenceManager.token}"
            )
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe({}, {})
        )
    }

    fun getMemberInfo(showNotificationSettingsDialog: () -> Unit) {
        compositeDisposable.add(
            userRepository.getMemberInfo(token = "Bearer ${SharedPreferenceManager.token}")
                .subscribeOn(Schedulers.io())
                .observeOn(AndroidSchedulers.mainThread())
                .subscribe(
                    {
                        if (it.success && it.data != null) {
                            val data = it.data
                            SharedPreferenceManager.can = data.can
                            SharedPreferenceManager.role = data.role.name
                            SharedPreferenceManager.isAuth = data.isAuth
                            if (
                                data.followingChannelUploadContentNotice == null &&
                                data.followingChannelLiveNotice == null &&
                                data.messageNotice == null
                            ) {
                                showNotificationSettingsDialog()
                            }
                        }
                    },
                    {}
                )
        )
    }
}
